==> ukui-screensaver_2.1.1.orig.tar.gz: ukui-screensaver/i18n_ts/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>AuthDialog</name>
    <message>
        <source>More Devices</source>
        <translation type="obsolete">选择其他设备</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="obsolete">使用生物识别认证</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">使用密码认证</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="486"/>
        <source>Retry</source>
        <translation>重试</translation>
    </message>
    <message>
        <source>UnLock</source>
        <translation type="obsolete">解锁</translation>
    </message>
    <message>
        <source>LoggedIn</source>
        <translation type="obsolete">已登录</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="248"/>
        <source>Password: </source>
        <translation>密码：</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="268"/>
        <location filename="../src/authdialog.cpp" line="299"/>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation>账户锁定%1分钟由于%2次错误尝试</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="281"/>
        <source>Password Incorrect, Please try again</source>
        <translation>密码错误，请重试</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="295"/>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation>认证失败，还剩%1次尝试机会</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="452"/>
        <source>Biometric Authentication</source>
        <translation>生物识别认证</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="464"/>
        <source>Password Authentication</source>
        <translation>密码认证</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="476"/>
        <source>Other Devices</source>
        <translation>其他设备</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="obsolete">指纹</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="obsolete">指静脉</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="obsolete">虹膜</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="obsolete">人脸</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="obsolete">声纹</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Please select other biometric devices</source>
        <translation type="obsolete">请选择其他生物识别设备</translation>
    </message>
    <message>
        <source>Device Type:</source>
        <translation type="obsolete">设备类型：</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation type="obsolete">设备名称：</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="96"/>
        <source>Current device: </source>
        <translation>当前设备：</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="152"/>
        <source>Identify failed, Please retry.</source>
        <translation>识别失败，请重试</translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="47"/>
        <source>Please select the biometric device</source>
        <translation>请选择生物设备</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="52"/>
        <source>Device type:</source>
        <translation>设备类型：</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="66"/>
        <source>Device name:</source>
        <translation>设备型号：</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="74"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
        <source>FingerPrint</source>
        <translation>指纹</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
        <source>FingerVein</source>
        <translation>指静脉</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
        <source>Iris</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="47"/>
        <source>Face</source>
        <translation>人脸</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="49"/>
        <source>VoicePrint</source>
        <translation>声纹</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <location filename="../VirtualKeyboard/src/keyboardwidget.ui" line="29"/>
        <source>KeyboardWidget</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <location filename="../src/lockwidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="54"/>
        <source>Date</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="67"/>
        <source>Time</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.cpp" line="149"/>
        <source>Guest</source>
        <translation>游客</translation>
    </message>
    <message>
        <location filename="../src/lockwidget.cpp" line="156"/>
        <source>SwitchUser</source>
        <translation>切换用户</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="30"/>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="35"/>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="96"/>
        <source>lock the screen immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="91"/>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="98"/>
        <source>activated by session idle signal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-screensaver_3.0.1.orig.tar.gz: ukui-screensaver/i18n_ts/zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AuthDialog</name>
    <message>
        <source>More Devices</source>
        <translation type="obsolete">选择其他设备</translation>
    </message>
    <message>
        <source>Biometric</source>
        <translation type="obsolete">使用生物识别认证</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">使用密码认证</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="454"/>
        <source>Retry</source>
        <translation>重试</translation>
    </message>
    <message>
        <source>UnLock</source>
        <translation type="obsolete">解锁</translation>
    </message>
    <message>
        <source>LoggedIn</source>
        <translation type="obsolete">已登录</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="237"/>
        <source>Password: </source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Account locked %1 minutes due to %2 fail attempts</source>
        <translation type="vanished">账户锁定%1分钟由于%2次错误尝试</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="253"/>
        <source>Password Incorrect, Please try again</source>
        <translation>密码错误，请重试</translation>
    </message>
    <message>
        <source>Authentication failure,there are still %1 remaining opportunities</source>
        <translation type="vanished">认证失败，还剩%1次尝试机会</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="419"/>
        <source>Biometric Authentication</source>
        <translation>生物识别认证</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="432"/>
        <source>Password Authentication</source>
        <translation>密码认证</translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="444"/>
        <source>Other Devices</source>
        <translation>其他设备</translation>
    </message>
</context>
<context>
    <name>BioDevices</name>
    <message>
        <source>FingerPrint</source>
        <translation type="obsolete">指纹</translation>
    </message>
    <message>
        <source>FingerVein</source>
        <translation type="obsolete">指静脉</translation>
    </message>
    <message>
        <source>Iris</source>
        <translation type="obsolete">虹膜</translation>
    </message>
    <message>
        <source>Face</source>
        <translation type="obsolete">人脸</translation>
    </message>
    <message>
        <source>VoicePrint</source>
        <translation type="obsolete">声纹</translation>
    </message>
</context>
<context>
    <name>BioDevicesWidget</name>
    <message>
        <source>Please select other biometric devices</source>
        <translation type="obsolete">请选择其他生物识别设备</translation>
    </message>
    <message>
        <source>Device Type:</source>
        <translation type="obsolete">设备类型：</translation>
    </message>
    <message>
        <source>Device Name:</source>
        <translation type="obsolete">设备名称：</translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="99"/>
        <source>Current device: </source>
        <translation>当前设备：</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="160"/>
        <source>Identify failed, Please retry.</source>
        <translation>识别失败，请重试</translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="47"/>
        <source>Please select the biometric device</source>
        <translation>请选择生物设备</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="52"/>
        <source>Device type:</source>
        <translation>设备类型：</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="68"/>
        <source>Device name:</source>
        <translation>设备型号：</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="78"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
        <source>FingerPrint</source>
        <translation>指纹</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
        <source>FingerVein</source>
        <translation>指静脉</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
        <source>Iris</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="47"/>
        <source>Face</source>
        <translation>人脸</translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="49"/>
        <source>VoicePrint</source>
        <translation>声纹</translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <location filename="../VirtualKeyboard/src/keyboardwidget.ui" line="29"/>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <location filename="../src/lockwidget.ui" line="14"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="54"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="67"/>
        <source>Time</source>
        <translation>时间</translation>
    </message>
    <message>
        <location filename="../src/lockwidget.cpp" line="247"/>
        <source>Guest</source>
        <translation>游客</translation>
    </message>
    <message>
        <source>SwitchUser</source>
        <translation type="vanished">切换用户</translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <source>lock</source>
        <translation type="vanished">锁定</translation>
    </message>
    <message>
        <source>SwitchUser</source>
        <translation type="vanished">切换用户</translation>
    </message>
    <message>
        <source>logout</source>
        <translation type="vanished">注销</translation>
    </message>
    <message>
        <source>reboot</source>
        <translation type="vanished">重启</translation>
    </message>
    <message>
        <source>shutdown</source>
        <translation type="vanished">关机</translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="109"/>
        <source>Lock Screen</source>
        <translation>锁屏</translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="124"/>
        <source>Switch User</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="138"/>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="152"/>
        <source>Restart</source>
        <translation>重启</translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="166"/>
        <source>Power Off</source>
        <translation>关机</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="66"/>
        <source>The screensaver is active.</source>
        <translation>屏幕保护程序已激活</translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="68"/>
        <source>The screensaver is inactive.</source>
        <translation>屏幕保护程序未激活</translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <source>exit(Esc)</source>
        <translation type="vanished">退出(Esc)</translation>
    </message>
    <message>
        <source>exit</source>
        <translation type="vanished">退出</translation>
    </message>
    <message>
        <location filename="../screensaver/screensaver.cpp" line="284"/>
        <source>Set as desktop wallpaper</source>
        <translation>设置为桌面壁纸</translation>
    </message>
    <message>
        <location filename="../screensaver/screensaver.cpp" line="294"/>
        <source>Automatic switching</source>
        <translation>自动切换</translation>
    </message>
</context>
<context>
    <name>SleepTime</name>
    <message>
        <location filename="../screensaver/sleeptime.cpp" line="70"/>
        <source>You have rested:</source>
        <translation>您已休息:</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="40"/>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation>启动锁屏到命令</translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="45"/>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="136"/>
        <source>lock the screen immediately</source>
        <translation>马上锁定屏幕</translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="48"/>
        <source>query the status of the screen saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="131"/>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="138"/>
        <source>activated by session idle signal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="55"/>
        <source>Screensaver for ukui-screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="59"/>
        <source>show on root window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="61"/>
        <source>show on window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="62"/>
        <source>window id</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
